### Persephone - a socio-economic-ecological model of European agricultural landscapes.
###
### This tests the core input and output functions.
###

@testset "Model configuration" begin
    properties = Dict{Symbol,Any}(:settings=>TESTSETTINGS)
    space = GridSpace((10,10), periodic=false)
    model = AgentBasedModel(Animal, space, properties=properties, warn=false)
    @test @param(core.configfile) == TESTPARAMETERS
    @test @param(core.startdate) == Date(2022, 1, 1)
    @test @param(nature.targetspecies) == ["Wolpertinger", "Wyvern"]
    @param(core.enddate) = Date(2022,1,3)
    @test @param(core.enddate) == Date(2022,1,3)
    #TODO test commandline parameters
end

@testset "Output functions" begin
    properties = Dict{Symbol,Any}(:settings=>TESTSETTINGS,
                                  :dataoutputs=>Vector{DataOutput}())
    space = GridSpace((10,10), periodic=false)
    model = AgentBasedModel(Animal, space, properties=properties, warn=false)
    # test that the output directory is created with all files
    outdir = @param(core.outdir)
    logstring = "Setting up output directory results_testsuite_$(Dates.today())_s1"
    @test_logs (:debug, logstring) min_level=Logging.Debug Ps.setupdatadir(model)
    @test isdir(outdir)
    @test isfile(joinpath(outdir, @param(core.landcovermap)))
    @test isfile(joinpath(outdir, @param(core.farmfieldsmap)))
    @test isfile(joinpath(outdir, @param(core.configfile)))
    @test isfile(joinpath(outdir, Ps.LOGFILE))
    # check whether the overwrite warning/protection works
    logstring = "Overwriting existing output directory $(outdir)."
    @test_logs (:warn, logstring) match_mode=:any Ps.setupdatadir(model)
    #TODO test overwrite protection (requires parameter mutability)
    rm(outdir, force=true, recursive=true)
    #TODO test that creating a DataOutput works, and outputs data with the required frequency
end
